<?xml version = "1.0" encoding = "UTF-8"?>
<xsl:stylesheet version = "1.0" xmlns:xsl = "http://www.w3.org/1999/XSL/Transform">
	<xsl:output method = "xml" version = "1.0" encoding = "UTF-8" standalone = "yes" indent="yes"/>
	<xsl:strip-space elements = "*"/>
	<!--======================================================================-->	
	<!--                        Root Element Template                         -->	
	<!-- The "Root Element Template" section specifies which template will be -->	
	<!-- invoked first thus determining the root element of the result tree.  -->	
	<!-- Note if the root element is a newly-defined element that is not      -->	
	<!-- associated with the input XML sources, then the template is invoked  -->	
	<!-- by name.  Otherwise, the template is invoked by applying matching    -->	
	<!-- template rules in XSLT.                                              -->	
	<!--======================================================================-->
	
	<!--xsl:template match = "/">
		<xsl:apply-templates/>
	</xsl:template-->
	<xsl:template match = "node() | @*">
		<xsl:copy>
			<xsl:apply-templates select = "node() | @*"/>
		</xsl:copy>
	</xsl:template>
	<!--======================================================================-->
	<!--                         Remaining Templates                          -->
	<!-- The remaining section defines the template rules. The last template  -->
	<!-- rule is a generic identity transformation used for moving complete   -->
	<!-- tree fragments from an input source to the result tree.              -->
	<!--                                                                      -->
	<!-- Note it should not be necessary to edit the remaining section of     -->
	<!-- this file!                                                           -->
	<!--======================================================================-->
	<!-- Composed element template											  -->
	<!--======================================================================-->
	<!--======================================================================-->
	<!--======================================================================-->
	<!--======================================================================-->


	<!--======================================================================-->	
	<!-- PREMIUM ETHWAY -->
	<!--======================================================================-->
	<xsl:template match = "ethwayMessaging">
		<xsl:variable name = "n" select = "@nbLine"/>
		<xsl:element name = "IPConfiguration">
			<xsl:if test = "@ethernetConfiguration">
				<xsl:attribute name = "ethernetConfiguration">
					<xsl:value-of select = "@ethernetConfiguration"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test = "@networkConfiguration">
				<xsl:attribute name = "networkConfiguration">
					<xsl:value-of select = "@networkConfiguration"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select = "IPNetwork|mask|gateway|comment()|processing-instruction()|text()"/>
		</xsl:element>
		<xsl:element name = "Messaging">
			<xsl:attribute name = "nbLine">
				<xsl:value-of select = "$n"/>
			</xsl:attribute>
			<xsl:apply-templates select = "EMConnection|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match = "EMConnection">
		<xsl:element name = "Connection">
			<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match = "EMLine">
		<xsl:element name = "MessLine">
			<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>



	<!--======================================================================-->

	<!-- PREMIUM REGULAR -->
	<!--======================================================================-->
	<xsl:template match = "intranetMessagingP">
		<xsl:variable name = "n" select = "@nbLine"/>
		<xsl:element name = "IPConfiguration">
			<xsl:if test = "@ethernetConfiguration">
				<xsl:attribute name = "ethernetConfiguration">
					<xsl:value-of select = "@ethernetConfiguration"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test = "@networkConfiguration">
				<xsl:attribute name = "networkConfiguration">
					<xsl:value-of select = "@networkConfiguration"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select = "IPNetwork|mask|gateway|comment()|processing-instruction()|text()"/>
		</xsl:element>
		<xsl:element name = "Messaging">
			<xsl:attribute name = "nbLine">
				<xsl:value-of select = "$n"/>
			</xsl:attribute>
			<xsl:if test = "@XWayProfile">
				<xsl:attribute name = "XWayProfile">
					<xsl:value-of select = "@XWayProfile"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select = "XWayAddress|IMPConnection|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match = "IMPConnection">
		<xsl:element name = "Connection">
			<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match = "IMPLine">
		<xsl:element name = "MessLine">
			<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>

	<!--======================================================================-->

	<!-- QUANTUM -->
	<!--======================================================================-->
	<xsl:template match = "intranetMessagingQ">	
		<xsl:element name = "Messaging">
			<xsl:attribute name = "nbLine">
				<xsl:value-of select = "@nbLine"/>
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="@CtrlIPAddress">
					<xsl:attribute name = "CtrlIPAddress">
						<xsl:value-of select = "@CtrlIPAddress"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name = "CtrlIPAddress">
						<xsl:value-of select = "1"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:element name = "Connection">
				<xsl:apply-templates select = "IMQLine|comment()|processing-instruction()|text()"/>	
			</xsl:element>	
		</xsl:element>
	</xsl:template>
	<!--======================================================================-->

	<xsl:template match = "IMQLine">		
			<xsl:element name = "MessLine">
				<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
			</xsl:element>
	</xsl:template>
	<!--======================================================================-->

	
	<!--======================================================================-->
	<!-- BANDWITH -->
	<!--======================================================================-->

	<xsl:template match = "bandwidth">	
		<xsl:element name = "bandwidth">
			<xsl:element name = "BWCalculation">
				<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<!--======================================================================-->
	<!--	until 3.0		
		Quantum Extended,		%IW  Read : readDISReg="1" readRef="0",
								%IW  Write: writeDISReg="1" writeRef="0",
								%M	 Read :	readDISReg="0" readRef="1"
								%M	 Write: writeDISReg="0" writeRef="1"


		Quantum Regular,		%IW  Read : readDISReg="0" readRef="1",
								%IW  Write: writeDISReg="0" writeRef="1",
								%M	 Read :	readDISReg="1" readRef="0"
								%M	 Write: writeDISReg="1" writeRef="0"

		so we introduce CtrlTypeVar attribute in IOScanning elt 
	-->
	<!--======================================================================-->

	<xsl:template match = "ethernet[@networkFamilyCatKey='NetworkFamily_Ethernet_Quantum_Extended']/quantum/TCPIP10100ExtendedConnection/IOScanning[not (@CtrlTypeVar)]">				
			<xsl:element name="IOScanning">
				<xsl:attribute name = "CtrlTypeVar">
						<xsl:value-of select = "1"/>
				</xsl:attribute>
				<xsl:apply-templates select = "@*|*|comment()|processing-instruction()|text()"/>		
			</xsl:element>
	</xsl:template>
	
</xsl:stylesheet>