<?xml version = "1.0" encoding = "UTF-8"?>
<xsl:transform xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" version = "1.0">
	<xsl:variable name = "ifFipio" select = "descendant::IOConf/IOBus/@busType='FIPIO'"/>
	<xsl:variable name = "ifQuantum" select = "descendant::IOConf/@gamme='QUANTUM'"/>
	<xsl:variable name = "ifMicro" select = "descendant::IOConf/@gamme='MICRO'"/>
	<xsl:template match = "text()"/>
	<xsl:template match = "IOConf">
		<xsl:variable name = "nbPCMCIA" select = "IOBus[@busType='LOCAL_QUANTUM']/rack/module[@moduleType='PLC']/subModule"/>
		<xsl:element name = "IOExchangeFile">
			<xsl:element name = "IOConf">
				<xsl:attribute name = "constructorName">
					<xsl:value-of select = "@constructorName"/>
				</xsl:attribute>
				<xsl:attribute name = "gamme">
					<xsl:value-of select = "@gamme"/>
				</xsl:attribute>
				<xsl:element name = "PLC">
					<xsl:element name = "partItem">
						<xsl:attribute name = "partNumber">
							<xsl:value-of select = "normalize-space(id(PLC/@productIdRef)/descendant::partNumber[1])"/>
						</xsl:attribute>
						<xsl:attribute name = "version">
							<xsl:value-of select = "'01.00'"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:element name = "equipInfo">
						<xsl:attribute name = "position">
							<xsl:value-of select = "PLC/@slotNumber"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:choose>
						<xsl:when test = "$ifQuantum">
							<xsl:element name = "configQuantum">
								<xsl:element name = "IOMapBlock">
									<xsl:apply-templates select = "IOBus"/>
								</xsl:element>
							</xsl:element>
							<xsl:call-template name = "cartridge">
								<xsl:with-param name = "pcmcia" select = "$nbPCMCIA"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name = "configATS">
								<xsl:apply-templates select = "IOBus"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name = "cartridge">
		<xsl:param name = "pcmcia"/>
		<xsl:if test = "$pcmcia">
			<xsl:variable name = "first" select = "$pcmcia[1]"/>
			<xsl:element name = "cartridge">
				<xsl:attribute name = "slotName">
					<xsl:choose>
						<xsl:when test = "$first/@slotNumber='0'">
							<xsl:value-of select = "'A'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select = "'B'"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:element name = "partItem">
					<xsl:attribute name = "partNumber">
						<xsl:value-of select = "$first/@partNumber"/>
					</xsl:attribute>
					<xsl:attribute name = "version">
						<xsl:value-of select = "'01.00'"/>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
			<xsl:variable name = "next" select = "$pcmcia[position()!=1]"/>
			<xsl:if test = "$next">
				<xsl:call-template name = "cartridge">
					<xsl:with-param name = "pcmcia" select = "$next"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match = "IOBus">
		<xsl:choose>
			<xsl:when test = "$ifQuantum">
				<xsl:variable name = "indexLocalBus">
					<xsl:for-each select = "following-sibling::*">
						<xsl:if test = "@busType='LOCAL_QUANTUM'">
							<xsl:value-of select = "position()+1"/>
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:element name = "busQuantum">
					<xsl:attribute name = "busType">
						<xsl:choose>
							<xsl:when test = "@busType='LOCAL_QUANTUM'">
								<xsl:value-of select = "'Local Quantum Bus'"/>
							</xsl:when>
							<xsl:when test = "@busType='RIOBUS'">
								<xsl:value-of select = "'RIO bus'"/>
							</xsl:when>
							<xsl:when test = "@busType='DIOBUS'">
								<xsl:value-of select = "'DIO bus'"/>
							</xsl:when>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name = "busNumber">
						<xsl:choose>
							<xsl:when test = "@busType='LOCAL_QUANTUM'">
								<xsl:value-of select = "1"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test = "position()=1">
										<xsl:value-of select = "$indexLocalBus"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select = "position()"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name = "headSlotLocation">
						<xsl:choose>
							<xsl:when test = "@busType='LOCAL_QUANTUM'">
								<xsl:value-of select = "../PLC/@slotNumber"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select = "@headSlotLocation"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:element name = "partItem">
						<xsl:attribute name = "partNumber">
							<xsl:choose>
								<xsl:when test = "@busType='LOCAL_QUANTUM'">
									<xsl:value-of select = "'LocalQuantumBus'"/>
								</xsl:when>
								<xsl:when test = "@busType='RIOBUS'">
									<xsl:value-of select = "'RIObus'"/>
								</xsl:when>
								<xsl:when test = "@busType='DIOBUS'">
									<xsl:value-of select = "'DIObus'"/>
								</xsl:when>
							</xsl:choose>
						</xsl:attribute>
						<xsl:attribute name = "version">
							<xsl:value-of select = "'01.00'"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:element name = "equipInfo">
						<xsl:attribute name = "position">
							<xsl:choose>
								<xsl:when test = "@busType='LOCAL_QUANTUM'">
									<xsl:value-of select = "1"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test = "position()=1">
											<xsl:value-of select = "$indexLocalBus"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select = "position()"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</xsl:element>
					<xsl:choose>
						<xsl:when test = "@busType='LOCAL_QUANTUM'">
							<xsl:element name = "dropQuantum">
								<xsl:attribute name = "dropType">
									<xsl:value-of select = "1"/>
								</xsl:attribute>
								<xsl:attribute name = "dropNumber">
									<xsl:value-of select = "1"/>
								</xsl:attribute>
								<xsl:element name = "partItem">
									<xsl:attribute name = "partNumber">
										<xsl:value-of select = "'QuantumDropforLocal'"/>
									</xsl:attribute>
									<xsl:attribute name = "version">
										<xsl:value-of select = "'01.00'"/>
									</xsl:attribute>
								</xsl:element>
								<xsl:element name = "equipInfo">
									<!--temporary topoAddress is mandatory-->
									<xsl:attribute name = "topoAddress">
										<xsl:value-of select = "1"/>
									</xsl:attribute>
									<xsl:attribute name = "position">
										<xsl:value-of select = "1"/>
									</xsl:attribute>
								</xsl:element>
								<xsl:apply-templates/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
				<xsl:when test = "$ifMicro">
					<xsl:choose>
					<xsl:when test = "@busType='BUSX'">
						<xsl:element name = "busATS">
							<xsl:attribute name = "name">
								<xsl:value-of select = "'XBusMicro'"/>
							</xsl:attribute>
							<xsl:apply-templates/>
						</xsl:element>
						<xsl:element name = "busATS">
							<xsl:attribute name = "name">
								<xsl:value-of select = "'CANopenMicroBasic'"/>
							</xsl:attribute>
							<xsl:for-each select = "../IOBus[@busType != 'BUSX']">
								<xsl:apply-templates select = "drop"/>
							</xsl:for-each>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
					</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
				<xsl:element name = "busATS">
					<xsl:attribute name = "name">
						<xsl:choose>
							<xsl:when test = "@busType='BUSX'">
								<xsl:value-of select = "'XBus'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select = "'Fipio'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<!--xsl:element name = "equipInfo">
						<xsl:attribute name = "position"/>
					</xsl:element-->
					<xsl:choose>
						<xsl:when test = "@busType='BUSX'">
							<!--xsl:apply-templates select = "rack"/-->
							<xsl:apply-templates/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select = "drop"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match = "rack[@rack mod 2 =0]">
		<xsl:choose>
			<xsl:when test = "$ifQuantum">
				<xsl:call-template name = "rackQuantum"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name = "rackATS">
					<xsl:element name = "partItem">
						<xsl:attribute name = "partNumber">
							<xsl:value-of select = "normalize-space(id(@productIdRef)/descendant::partNumber[1])"/>
						</xsl:attribute>
						<xsl:attribute name = "version">
							<xsl:value-of select = "'01.00'"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:element name = "equipInfo">
						<xsl:attribute name = "position">
							<xsl:value-of select = "@rack div 2"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:variable name = "rackNumber" select = "@rack+1"/>
					<xsl:if test = "following-sibling::rack[1][@rack=$rackNumber]">
						<xsl:element name = "auxiliaryRackATS">
							<xsl:element name = "partItem">
								<xsl:attribute name = "partNumber">
									<xsl:value-of select = "normalize-space(id(following-sibling::rack[1]/@productIdRef)/descendant::partNumber[1])"/>
								</xsl:attribute>
								<xsl:attribute name = "version">
									<xsl:value-of select = "'01.00'"/>
								</xsl:attribute>
							</xsl:element>
							<xsl:element name = "equipInfo">
								<xsl:attribute name = "position">
									<xsl:value-of select = "@rack div 2"/>
								</xsl:attribute>
							</xsl:element>
							<xsl:for-each select = "following-sibling::rack[1]/module[@moduleType='POWERSUPPLY']">
								<xsl:call-template name = "module">
									<xsl:with-param name = "index" select = "8"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:element>
					</xsl:if>
					<xsl:for-each select = "module">
						<xsl:call-template name = "module">
							<xsl:with-param name = "index" select = "0"/>
						</xsl:call-template>
					</xsl:for-each>
					<xsl:if test = "following-sibling::rack[1][@rack=$rackNumber]">
						<xsl:for-each select = "following-sibling::rack[1]/module[@moduleType!='POWERSUPPLY']">
							<xsl:call-template name = "module">
								<xsl:with-param name = "index" select = "8"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:if>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match = "rack[@rack mod 2 =1]">
		<xsl:if test = "$ifQuantum">
			<xsl:call-template name = "rackQuantum"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match = "rack[@rack ='Ext.']">
		<xsl:if test = "$ifQuantum">
			<xsl:call-template name = "rackQuantum"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name = "module" match = "module">
		<xsl:param name = "index"/>
		<xsl:choose>
			<xsl:when test = "$ifQuantum">
				<xsl:element name = "moduleQuantum">
					<xsl:choose>
						<xsl:when test = "@moduleType='DIOHEAD'">
							<xsl:attribute name = "subsetFlag">
								<xsl:value-of select = "'128'"/>
							</xsl:attribute>
						</xsl:when>
						<xsl:when test = "@moduleType='RIOHEAD'">
							<xsl:attribute name = "subsetFlag">
								<xsl:value-of select = "'512'"/>
							</xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:element name = "partItem">
						<xsl:attribute name = "partNumber">
							<xsl:value-of select = "normalize-space(id(@productIdRef)/descendant::partNumber[1])"/>
						</xsl:attribute>
						<xsl:attribute name = "version">
							<xsl:value-of select = "'01.00'"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:element name = "equipInfo">
						<!--temporary topoAddress is mandatory-->
						<xsl:attribute name = "topoAddress">
							<xsl:value-of select = "@module"/>
						</xsl:attribute>
						<xsl:attribute name = "position">
							<xsl:value-of select = "@module"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test = "@moduleType='POWERSUPPLY'">
						<xsl:call-template name = "PowerSupply"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name = "moduleATS">
							<xsl:if test = "@moduleType='PLC'">
								<xsl:attribute name = "UCMod">
									<xsl:value-of select = "1"/>
								</xsl:attribute>
								<xsl:if test = "$ifFipio">
									<xsl:element name = "masteredBusInfo">
										<xsl:attribute name = "name">
											<xsl:value-of select = "'Fipio'"/>
										</xsl:attribute>
									</xsl:element>
								</xsl:if>
								<xsl:if test = "$ifMicro">
									<xsl:element name = "masteredBusInfo">
										<xsl:attribute name = "name">
											<xsl:value-of select = "'CANopenMicroBasic'"/>
										</xsl:attribute>
									</xsl:element>
								</xsl:if>
							</xsl:if>
							<xsl:element name = "partItem">
								<xsl:attribute name = "partNumber">
									<xsl:value-of select = "normalize-space(id(@productIdRef)/descendant::partNumber[1])"/>
								</xsl:attribute>
								<xsl:attribute name = "version">
									<xsl:value-of select = "'01.00'"/>
								</xsl:attribute>
							</xsl:element>
							<xsl:element name = "equipInfo">
								<xsl:attribute name = "position">
									<xsl:value-of select = "number(@module)+$index"/>
								</xsl:attribute>
							</xsl:element>
							<xsl:apply-templates select = "subModule"/>
						</xsl:element>
						<!-- management of the particular PLC that is in fact made of a CPU and a ETH module-->
						
						<!--xsl:if test = "normalize-space(id(@productIdRef)/descendant::partNumber[1])='TSXP573634M'">
							<xsl:element name = "moduleATS">
								<xsl:element name = "partItem">
									<xsl:attribute name = "partNumber">
										<xsl:value-of select = "'TSXETYPORT'"/>
									</xsl:attribute>
									<xsl:attribute name = "version">
										<xsl:value-of select = "'01.00'"/>
									</xsl:attribute>
								</xsl:element>
								<xsl:element name = "equipInfo">
									<xsl:attribute name = "position">
										<xsl:value-of select = "number(@module)+$index+1"/>
									</xsl:attribute>
								</xsl:element>
							</xsl:element>
						</xsl:if-->
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match = "subModule">
		<xsl:if test = "@slotNumber!=''">
			<xsl:element name = "subModule">
				<xsl:element name = "partItem">
					<xsl:attribute name = "partNumber">
						<xsl:value-of select = "@partNumber"/>
					</xsl:attribute>
					<xsl:attribute name = "version">
						<xsl:value-of select = "'01.00'"/>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name = "equipInfo">
					<xsl:attribute name = "position">
						<xsl:value-of select = "@slotNumber"/>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match = "drop">
		<xsl:choose>
			<xsl:when test = "$ifQuantum">
				<xsl:element name = "dropQuantum">
					<xsl:attribute name = "dropType">
						<xsl:choose>
							<xsl:when test = "@type='DIO'">
								<xsl:value-of select = "2"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select = "1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name = "dropNumber">
						<xsl:value-of select = "@number"/>
					</xsl:attribute>
					<xsl:attribute name = "headSlotLocation">
						<xsl:value-of select = "@headSlotLocation"/>
					</xsl:attribute>
					<xsl:element name = "partItem">
						<xsl:attribute name = "partNumber">
							<xsl:choose>
								<xsl:when test = "@type='DIO'">
									<xsl:value-of select = "'QuantumDropforDIO'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select = "'QuantumDropforRIO'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:attribute name = "version">
							<xsl:value-of select = "'01.00'"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:element name = "equipInfo">
						<!--temporary topoAddress is mandatory-->
						<xsl:attribute name = "topoAddress">
							<xsl:value-of select = "@number"/>
						</xsl:attribute>
						<xsl:attribute name = "position">
							<xsl:value-of select = "@number"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:apply-templates/>
					<!--xsl:apply-templates select = "rack"/-->
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name = "dropATS">
					<xsl:element name = "equipInfo">
						<xsl:attribute name = "position">
							<xsl:value-of select = "@number"/>
						</xsl:attribute>
					</xsl:element>
					<xsl:choose>
						<xsl:when test = "$ifMicro">
							<xsl:call-template name = "moduleCan"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name = "selectmoduleFip"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name = "PowerSupply">
		<xsl:element name = "powerSupply">
			<xsl:element name = "partItem">
				<xsl:attribute name = "partNumber">
					<xsl:value-of select = "normalize-space(id(@productIdRef)/descendant::partNumber[1])"/>
				</xsl:attribute>
				<xsl:attribute name = "version">
					<xsl:value-of select = "'01.00'"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name = "equipInfo">
				<xsl:attribute name = "position">
					<xsl:value-of select = "number(@module)"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name = "rackQuantum">
		<!--xsl:if test = "ifQuantum"-->
		<xsl:element name = "rackQuantum">
			<xsl:element name = "partItem">
				<xsl:attribute name = "partNumber">
					<xsl:value-of select = "normalize-space(id(@productIdRef)/descendant::partNumber[1])"/>
				</xsl:attribute>
				<xsl:attribute name = "version">
					<xsl:value-of select = "'01.00'"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name = "equipInfo">
				<!--temporary topoAddress is mandatory-->
				<xsl:attribute name = "topoAddress">
					<xsl:value-of select = "@rack"/>
				</xsl:attribute>
				<xsl:attribute name = "position">
					<xsl:choose>
						<xsl:when test = "@rack='Ext.'">
							<xsl:value-of select = "2"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select = "@rack"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</xsl:element>
			<xsl:apply-templates select = "module"/>
		</xsl:element>
		<!--/xsl:if-->
	</xsl:template>
	<xsl:template name = "selectmoduleFip">
		<xsl:choose>
			<xsl:when test = "starts-with(normalize-space(id(module/@productIdRef)/descendant::partNumber[1]),'TSXP57')">
				<xsl:call-template name = "moduleFip">
					<xsl:with-param name="FipioDevice" select="'TSX57'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test = "starts-with(normalize-space(id(module/@productIdRef)/descendant::partNumber[1]),'TSXPCI57')">
						<xsl:call-template name ="moduleFip">
							<xsl:with-param name="FipioDevice" select="'TSX57'" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test = "starts-with(normalize-space(id(module/@productIdRef)/descendant::partNumber[1]),'TPCX57')">
								<xsl:call-template name ="moduleFip">
									<xsl:with-param name="FipioDevice" select="'TSX57'" />
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test = "starts-with(normalize-space(id(module/@productIdRef)/descendant::partNumber[1]),'TSX 37')">
										<xsl:call-template name = "moduleFip">
											<xsl:with-param name="FipioDevice" select="'TSX37'" />
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name = "moduleFip"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name = "moduleFip">
		<xsl:param name="FipioDevice" select= "normalize-space(id(module/@productIdRef)/descendant::partNumber[1])"/>
		<xsl:element name = "moduleATS">
			<xsl:element name = "partItem">
				<xsl:attribute name = "partNumber">
					<xsl:value-of select = "$FipioDevice"/>
				</xsl:attribute>
				<xsl:attribute name = "version">
					<xsl:value-of select = "'01.00'"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name = "equipInfo">
				<xsl:attribute name = "position">
					<xsl:value-of select = "0"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
		<xsl:for-each select = "descendant::subModule">
			<xsl:element name = "moduleATS">
				<xsl:element name = "partItem">
					<xsl:attribute name = "partNumber">
						<xsl:choose>
							<xsl:when test = "@partNumber='TSXFPP10'">
								<xsl:value-of select = "'TSXFPP010@OTHER'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select = "@partNumber"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name = "version">
						<xsl:value-of select = "'01.00'"/>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name = "equipInfo">
					<xsl:attribute name = "position">
						<xsl:choose>
							<xsl:when test = "@subModuleType='1'">
								<xsl:value-of select = "'-1'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test = "@subModuleType='3'">
										<xsl:value-of select = "'-1'"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select = "'1'"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name = "moduleCan">
		<xsl:element name = "moduleATS">
			<xsl:element name = "partItem">
				<xsl:attribute name = "partNumber">
					<xsl:value-of select = "normalize-space(id(module/@productIdRef)/descendant::partNumber[1])"/>
				</xsl:attribute>
				<xsl:attribute name = "version">
					<xsl:value-of select = "'01.00'"/>
				</xsl:attribute>
			</xsl:element>
			<xsl:element name = "equipInfo">
				<xsl:attribute name = "position">
					<xsl:value-of select = "0"/>
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
		<xsl:for-each select = "descendant::subModule">
			<xsl:element name = "moduleATS">
				<xsl:element name = "partItem">
					<xsl:attribute name = "partNumber">
						<xsl:value-of select = "@partNumber"/>
					</xsl:attribute>
					<xsl:attribute name = "version">
						<xsl:value-of select = "'01.00'"/>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name = "equipInfo">
					<xsl:attribute name = "position">
						<xsl:choose>
							<xsl:when test = "@subModuleType='1'">
								<xsl:value-of select = "'-1'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select = "'1'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
</xsl:transform>