<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" standalone="yes" indent="yes"/>
	<xsl:preserve-space elements="*"/>
	<!--======================================================================-->
	<!--                        LEVEL of the file		                      -->
	<xsl:variable name="FileVersion" select="31"/>
	<!--======================================================================-->
	<!--======================================================================-->
	<!--                        LEVEL TO REACH		                          -->
	<xsl:variable name="DTDToLevel" select="0"/>
	<!--======================================================================-->
	<!--======================================================================-->
	<!--                        STARTING LEVEL		                          -->
	<xsl:variable name="DTDLevel">
		<xsl:choose>
			<xsl:when test="//fileHeader/@DTDVersion">
				<xsl:value-of select="//fileHeader/@DTDVersion"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!--======================================================================-->
	<!--======================================================================-->
	<!--                        Root Element Template                         -->
	<!-- The "Root Element Template" section specifies which template will be -->
	<!-- invoked first thus determining the root element of the result tree.  -->
	<!-- Note if the root element is a newly-defined element that is not      -->
	<!-- associated with the input XML sources, then the template is invoked  -->
	<!-- by name.  Otherwise, the template is invoked by applying matching    -->
	<!-- template rules in XSLT.                                              -->
	<!--======================================================================-->
	<xsl:template match="node() | @*|processing-instruction()|text()">
		<xsl:copy>
			<xsl:apply-templates select="node() | @*|processing-instruction()|text()"/>
		</xsl:copy>
	</xsl:template>
	<!--======================================================================-->
	<!--                         Remaining Templates                          -->
	<!-- The remaining section defines the template rules. The last template  -->
	<!-- rule is a generic identity transformation used for moving complete   -->
	<!-- tree fragments from an input source to the result tree.              -->
	<!--                                                                      -->
	<!-- Note it should not be necessary to edit the remaining section of     -->
	<!-- this file!                                                           -->
	<!--======================================================================-->
	<!-- Composed element template -->
	<!--======================================================================-->
	<!--                        SET the result level (product & dtd)           -->
	<!--======================================================================-->
	<!-- DTDVersion -->
	<xsl:template match="@DTDVersion">
		<xsl:choose>
			<xsl:when test="( $DTDToLevel > 1)">
				<xsl:attribute name="DTDVersion">
					<xsl:value-of select="$DTDToLevel"/>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise/>
			<!-- GO BACK TO FIRST VERSION => NO DTDVERSION-->
		</xsl:choose>
	</xsl:template>
	<xsl:template match="@product">
		<xsl:choose>
			<xsl:when test="(0 = $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V1.0.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(1 = $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.0.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(2 = $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.0.2 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(3= $DTDToLevel)">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.1.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(4= $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.1.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(5= $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.1.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(6 = $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V2.3.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:when test="(30 = $DTDToLevel )">
				<xsl:attribute name="product">
					<xsl:text>Unity Pro V3.0.0 - (downgraded from</xsl:text>
					<xsl:value-of select="."/>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<!--                      transformers							          -->
	<!--======================================================================-->
	<!--=========== MODIF AD 17/1/07 ==========================-->
	<!--=========== GLOBAL Variables for commmunication IOScanning ==========================-->
	<xsl:variable name="IOS_remove_char">%MmWwIi</xsl:variable>
	<xsl:variable name="IOS_replace_char"/>
	<!--======================================================-->
	<!--=========================2-1 (unity v2.0.0) [# v2.0.0 = 1 ]===================================-->
	<xsl:template match="//IOConf/PLC/partItem[@partNumber='140CPU53414A/U']/@partNumber">
		<xsl:choose>
			<xsl:when test="(2 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>140CPU53414A</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/partItem[@partNumber='140CPU43412A/U']/@partNumber">
		<xsl:choose>
			<xsl:when test="(2 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>140CPU43412A</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configQuantum/IOMapBlock/busQuantum/dropQuantum/rackQuantum/moduleQuantum/partItem[@partNumber='140CPU53414A/U']/@partNumber">
		<xsl:choose>
			<xsl:when test="(2 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>140CPU53414A</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configQuantum/IOMapBlock/busQuantum/dropQuantum/rackQuantum/moduleQuantum/partItem[@partNumber='140CPU43412A/U']/@partNumber">
		<xsl:choose>
			<xsl:when test="(2 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>140CPU43412A</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--=========================3-2 (unity v2.0.2)[#v2.0.2 = 2 ]===================================-->
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/ @partNumber='FSDM8']/configModule/channelATS[ @ASFCatKey='STDP_FSD_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FSD_ADM_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='FSDC8']/configModule/channelATS[@ASFCatKey='STDP_FSD_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FSD_ADM_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='OTHERFSD']/configModule/channelATS[@ASFCatKey='STDP_FSD_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FSD_ADM_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS/partItem[@partNumber='170ANR12090' or @partNumber='170ANR12091']/@family">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="family">
					<xsl:text>Fipio Momentum Analog</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='170ANR12090' or partItem/@partNumber='170ANR12091']/configModule/channelATS[@ASFCatKey='STDP_ANR_FED_P_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FED_P_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='XGKS130421' or partItem/@partNumber='XGPS1304202']/configModule/channelATS[@ASFCatKey='INDUCTEL_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FSD_P_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='TSXEEF16D2']/configModule/channelATS[@ASFCatKey='IP67In16_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>IP67In_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='TSXEEF08D2']/configModule/channelATS[@ASFCatKey='IP67In8_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>IP67In_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='170ADM39010']/configModule/channelATS[@ASFCatKey='STDP_FSD_ADM_MASTER']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(3 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>STDP_FSD_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--=========================4-3 (unity v2.1.0)[# v2.1.0 = 3 ]===================================-->
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS/moduleATS[partItem/@partNumber='TSXESF08T22']/configModule/channelATS[@ASFCatKey='IP67MixteOut_MASTER' and @number='0']/@ASFCatKey">
		<xsl:choose>
			<xsl:when test="(4 > $DTDToLevel )">
				<xsl:attribute name="ASFCatKey">
					<xsl:text>IP67MixteIn_MASTER</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS[moduleATS/partItem/@family='Fipio Waterproof IP67']/partItem/@partNumber">
		<xsl:choose>
			<xsl:when test="(4 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>WaterproofIP67Fipiodrop</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS[moduleATS/partItem/@family='Fipio Waterproof IP65']/partItem/@partNumber">
		<xsl:choose>
			<xsl:when test="(4 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>WaterproofIP65Fipiodrop</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--========================= unity v2.1.0 = 5 ===================================-->
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='XBus']/rackATS/moduleATS/subModule[partItem/@partNumber='TSXSCP114/1114']/partItem/@partNumber">
		<xsl:choose>
			<xsl:when test="(5 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>TSXSCP114</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//IOConf/PLC/configATS/busATS[@name='Fipio']/dropATS[moduleATS/partItem/@family='Fipio Waterproof IP65']/partItem/@partNumber">
		<xsl:choose>
			<xsl:when test="(5 > $DTDToLevel )">
				<xsl:attribute name="partNumber">
					<xsl:text>WaterproofIP65Fipiodrop</xsl:text>
				</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--=========================5-4(unity v2.1.0) variable part ===================================-->
	<xsl:template match="//instanceElementDesc[not(value) and not(attribute) ]">
		<xsl:choose>
			<xsl:when test="(5 > $DTDToLevel )"/>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//instanceElementDesc/comment">
		<xsl:choose>
			<xsl:when test="(5 > $DTDToLevel )"/>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//variables/attribute[@name='Save']">
		<xsl:choose>
			<xsl:when test="(5 > $DTDToLevel )">
				<xsl:variable name="typ" select="parent::node()/@typeName"/>
				<xsl:if test="$typ='INT' or $typ='DINT' or $typ='STRING' or $typ='DWORD' or $typ='BYTE' or $typ='DT' or $typ='WORD' or $typ='REAL' or $typ='TOD' or $typ='UINT' or $typ='DATE' or $typ='BOOL' or $typ='UDINT' or $typ='TIME' or $typ='EBOOL'">
					<xsl:element name="attribute">
						<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--=========================[# v2.3.0 = 6 ]===================================-->
	<!--COMP DB-->
	<xsl:template match="//variables [@typeName='COMP_DB']">
		<xsl:choose>
			<xsl:when test="($DTDLevel>5 )">
				<xsl:choose>
					<xsl:when test="(6 > $DTDToLevel )">
					<!--removed--></xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- efb vs ef -->
	<xsl:template match="//FFBBlock [@typeName='COMP_DB']/@instanceName">
		<xsl:choose>
			<xsl:when test="($DTDLevel>5)">
				<xsl:choose>
					<xsl:when test="(6 > $DTDToLevel )">
						<xsl:attribute name="instanceName"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--=========================[# v3.0.0 = 30 ]===================================-->
	<!--COMP DB-->
	<xsl:template match="//FBSource[@nameOfFBType='COMP_DB_DFB']">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
					<!--removed--></xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//variables [@typeName='COMP_DB_DFB']">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
					<!--removed--></xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//FFBBlock [@typeName='COMP_DB_DFB']/@typeName">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:attribute name="typeName">COMP_DB</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="//FFBBlock [@typeName='COMP_DB_DFB']/@instanceName">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:attribute name="instanceName"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--COMMUNICATION GRAMMAR CHANGED-->
	<xsl:template match="@XWayProfile">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:variable name="this" select="."/>
						<xsl:choose>
							<xsl:when test="($this =1)">
								<xsl:attribute name="XWayProfile">true</xsl:attribute>
							</xsl:when>
							<xsl:when test="($this =true)">
								<xsl:attribute name="XWayProfile">true</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="XWayProfile">false</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="@accessControl">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:variable name="this" select="."/>
						<xsl:choose>
							<xsl:when test="($this =1)">
								<xsl:attribute name="accessControl">true</xsl:attribute>
							</xsl:when>
							<xsl:when test="($this =true)">
								<xsl:attribute name="accessControl">true</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="accessControl">false</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="@validIP">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:variable name="this" select="."/>
						<xsl:choose>
							<xsl:when test="($this =1)">
								<xsl:attribute name="validIP">true</xsl:attribute>
							</xsl:when>
							<xsl:when test="($this =true)">
								<xsl:attribute name="validIP">true</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="validIP">false</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="@validXWAY">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:variable name="this" select="."/>
						<xsl:choose>
							<xsl:when test="($this =1)">
								<xsl:attribute name="validXWAY">true</xsl:attribute>
							</xsl:when>
							<xsl:when test="($this =true)">
								<xsl:attribute name="validXWAY">true</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="validXWAY">false</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<!-- PREMIUM ETHWAY -->
	<!--======================================================================-->
	<xsl:template match="ETHWAY/IPConfiguration">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )"/>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="DeviceName">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )"/>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="CtrlIPAddress">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )"/>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="ETHWAY/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="EMLine">
							<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="ETHWAY">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:variable name="this" select="."/>
						<xsl:variable name="Mess" select="$this/Messaging"/>
						<xsl:variable name="Conf" select="$this/IPConfiguration"/>
						<xsl:variable name="Connect" select="$Mess/Connection"/>
						<xsl:variable name="Line" select="$Connect/MessLine"/>
						<xsl:element name="ETHWAY">
							<xsl:element name="ethwayMessaging">
								<xsl:apply-templates select="$Mess/@* |$Mess/XWayAddress"/>
								<xsl:apply-templates select="$Conf/@*|$Conf/*|$Conf/comment()|$Conf/processing-instruction()|$Conf/text()"/>
								<xsl:element name="EMConnection">
									<xsl:apply-templates select="$Connect/@*|$Line|$Connect/comment()|$Connect/processing-instruction()|$Connect/text()"/>
								</xsl:element>
							</xsl:element>
							<xsl:apply-templates select="commonWords|SNMP|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<!-- PREMIUM REGULAR -->
	<!--======================================================================-->
	<xsl:template match="ASLine/@access">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )"/>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="bandwidth">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="bandwidth">
							<xsl:variable name="Calc" select="BWCalculation/@*"/>
							<xsl:apply-templates select="$Calc"/>
							<xsl:apply-templates select="@*|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="ETYIntranet/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IMPLine">
							<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="ETYIntranet">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="ETYIntranet">
							<xsl:variable name="this" select="."/>
							<xsl:variable name="Mess" select="$this/Messaging"/>
							<xsl:variable name="Conf" select="$this/IPConfiguration"/>
							<xsl:variable name="Connect" select="$Mess/Connection"/>
							<xsl:variable name="Line" select="$Connect/MessLine"/>
							<xsl:element name="intranetMessagingP">
								<xsl:apply-templates select="$Mess/@*"/>
								<xsl:apply-templates select="$Conf/@*"/>
								<xsl:apply-templates select="$Conf/*|$Conf/comment()|$Conf/processing-instruction()|$Conf/text()"/>
								<xsl:apply-templates select="$Mess/XWayAddress"/>
								<xsl:element name="IMPConnection">
									<xsl:apply-templates select="$Connect/@*|$Line|$Connect/comment()|$Connect/processing-instruction()|$Connect/text()"/>
								</xsl:element>
							</xsl:element>
							<xsl:apply-templates select="IOScanning|globalData|SNMP|addressServer|bandwidth|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<!-- PREMIUM COPRO -->
	<!--======================================================================-->
	<xsl:template match="intranetCoproP/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IMPLine">
							<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ETYIntranet/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IMPLine">
							<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="intranetCoproP/IPConfiguration">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )"/>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="intranetCoproP">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="intranetCoproP">
							<xsl:variable name="this" select="."/>
							<xsl:variable name="Mess" select="$this/Messaging"/>
							<xsl:variable name="Conf" select="$this/IPConfiguration"/>
							<xsl:variable name="Connect" select="$Mess/Connection"/>
							<xsl:variable name="Line" select="$Connect/MessLine"/>
							<xsl:element name="intranetMessagingP">
								<xsl:apply-templates select="$Mess/@*"/>
								<xsl:apply-templates select="$Conf/@*"/>
								<xsl:apply-templates select="$Conf/*|$Conf/comment()|$Conf/processing-instruction()|$Conf/text()"/>
								<xsl:apply-templates select="$Mess/XWayAddress"/>
								<xsl:element name="IMPConnection">
									<xsl:apply-templates select="$Connect/@*|$Line|$Connect/comment()|$Connect/processing-instruction()|$Connect/text()"/>
								</xsl:element>
							</xsl:element>
							<xsl:apply-templates select="IOScanning|globalData|SNMP|addressServer|bandwidth|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--===========================================================================================================================================-->
	<!-- QUANTUM modif AD 2007_01_15 -->
	<!-- 1) Reverse the IP @ for the Messaging Quantum Regular & Extended -->
	<!-- as this file is only called from version v3.0 or higher, we always reverse the IP addresses -->
	<!-- 2) reverse the switch between %M and %IW for IOS Quantum Extended -->
	<!-- 3) remove the %M, %MW, %I and %IW in the RDMaster and WRMaster attributes for Quantum IOS (Extended, Regular and TCPIP10100 -->
	<!--==========================================================================================================================================-->
	<xsl:template match="TCPIP10100RegularConnection/Messaging/Connection/MessLine/IPAddress">
		<xsl:variable name="varIP0" select="./@IP0"/>
		<xsl:variable name="varIP1" select="./@IP1"/>
		<xsl:variable name="varIP2" select="./@IP2"/>
		<xsl:variable name="varIP3" select="./@IP3"/>
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IPAddress">
							<xsl:attribute name="IP0">
								<xsl:value-of select="$varIP3"/>
							</xsl:attribute>
							<xsl:attribute name="IP1">
								<xsl:value-of select="$varIP2"/>
							</xsl:attribute>
							<xsl:attribute name="IP2">
								<xsl:value-of select="$varIP1"/>
							</xsl:attribute>
							<xsl:attribute name="IP3">
								<xsl:value-of select="$varIP0"/>
							</xsl:attribute>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="TCPIP10100RegularConnection/Messaging/@CtrlIPAddress">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:attribute name="CtrlIPAddress">1</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="TCPIP10100ExtendedConnection/Messaging/Connection/MessLine/IPAddress">
		<xsl:variable name="varIP0" select="./@IP0"/>
		<xsl:variable name="varIP1" select="./@IP1"/>
		<xsl:variable name="varIP2" select="./@IP2"/>
		<xsl:variable name="varIP3" select="./@IP3"/>
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IPAddress">
							<xsl:attribute name="IP0">
								<xsl:value-of select="$varIP3"/>
							</xsl:attribute>
							<xsl:attribute name="IP1">
								<xsl:value-of select="$varIP2"/>
							</xsl:attribute>
							<xsl:attribute name="IP2">
								<xsl:value-of select="$varIP1"/>
							</xsl:attribute>
							<xsl:attribute name="IP3">
								<xsl:value-of select="$varIP0"/>
							</xsl:attribute>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="TCPIP10100ExtendedConnection/Messaging/@CtrlIPAddress">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:attribute name="CtrlIPAddress">1</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--===== fix IOS Quantum Extended reinverse the %IW and %M ====-->
	<xsl:template match="TCPIP10100ExtendedConnection/IOScanning/IOSLine">
		<xsl:variable name="varReadDISReg" select="./@readDISReg"/>
		<xsl:variable name="varReadRef" select="./@readRef"/>
		<xsl:variable name="varWriteDISReg" select="./@writeDISReg"/>
		<xsl:variable name="varWriteRef" select="./@writeRef"/>
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IOSLine">
							<xsl:apply-templates select="@*"/>
							<xsl:if test="($varReadDISReg != $varReadRef)">
								<xsl:attribute name="readDISReg">
									<xsl:value-of select="$varReadRef"/>
								</xsl:attribute>
								<xsl:attribute name="readRef">
									<xsl:value-of select="$varReadDISReg"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:if test="($varWriteDISReg != $varWriteRef)">
								<xsl:attribute name="writeDISReg">
									<xsl:value-of select="$varWriteRef"/>
								</xsl:attribute>
								<xsl:attribute name="writeRef">
									<xsl:value-of select="$varWriteDISReg"/>
								</xsl:attribute>
							</xsl:if>
							<xsl:apply-templates select="./IPAddress"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="TCPIP10100ExtendedConnection/IOScanning/@CtrlTypeVar">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:attribute name="CtrlTypeVar">1</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Troncation of %MW %M %I %IW for all Networks => this shouldn't be called on M340-->
	<xsl:template match="TCPIP10100ExtendedConnection/IOScanning/IOSLine/@RDMaster">
		<xsl:variable name="varRDMaster1" select="."/>
		<xsl:attribute name="RDMaster">
			<xsl:value-of select="translate($varRDMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="TCPIP10100ExtendedConnection/IOScanning/IOSLine/@WRMaster">
		<xsl:variable name="varWRMaster1" select="."/>
		<xsl:attribute name="WRMaster">
			<xsl:value-of select="translate($varWRMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="TCPIP10100RegularConnection/IOScanning/IOSLine/@RDMaster">
		<xsl:variable name="varRDMaster1" select="."/>
		<xsl:attribute name="RDMaster">
			<xsl:value-of select="translate($varRDMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="TCPIP10100RegularConnection/IOScanning/IOSLine/@WRMaster">
		<xsl:variable name="varWRMaster1" select="."/>
		<xsl:attribute name="WRMaster">
			<xsl:value-of select="translate($varWRMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="TCPIP10100/IOScanning/IOSLine/@RDMaster">
		<xsl:variable name="varRDMaster1" select="."/>
		<xsl:attribute name="RDMaster">
			<xsl:value-of select="translate($varRDMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="TCPIP10100/IOScanning/IOSLine/@WRMaster">
		<xsl:variable name="varWRMaster1" select="."/>
		<xsl:attribute name="WRMaster">
			<xsl:value-of select="translate($varWRMaster1, $IOS_remove_char, $IOS_replace_char)"/>
		</xsl:attribute>
	</xsl:template>
	<!--=====================================================================================================================-->
	<!-- QUANTUM END modif AD 2007_01_15 -->
	<!--=====================================================================================================================-->
	<!--======================================================================-->
	<!-- QUANTUM REGULAR -->
	<!--======================================================================-->
	<xsl:template match="TCPIP10100RegularConnection/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="IMQLine">
							<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="TCPIP10100RegularConnection">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="TCPIP10100RegularConnection">
							<xsl:variable name="this" select="."/>
							<xsl:variable name="Mess" select="$this/Messaging"/>
							<xsl:variable name="Line" select="$Mess/Connection/MessLine"/>
							<xsl:apply-templates select="@*"/>
							<xsl:apply-templates select="IPConfiguration"/>
							<xsl:element name="intranetMessagingQ">
								<xsl:apply-templates select="$Mess/@*|$Mess/comment()|$Mess/processing-instruction()|$Mess/text()"/>
								<xsl:apply-templates select="$Line"/>
							</xsl:element>
							<xsl:apply-templates select="IOScanning|globalData|SNMP|addressServer|bandwidth|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<!-- QUANTUM COPRO -->
	<!--======================================================================-->
	<xsl:template match="TCPIP10100ExtendedConnection/Messaging/Connection/MessLine">
		<xsl:choose>
			<xsl:when test="(30 > $DTDToLevel )">
				<xsl:element name="IMQLine">
					<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--======================================================================-->
	<xsl:template match="TCPIP10100ExtendedConnection">
		<xsl:choose>
			<xsl:when test="($DTDLevel>29 )">
				<xsl:choose>
					<xsl:when test="(30 > $DTDToLevel )">
						<xsl:element name="TCPIP10100ExtendedConnection">
							<xsl:variable name="this" select="."/>
							<xsl:variable name="Mess" select="$this/Messaging"/>
							<xsl:variable name="Line" select="$Mess/Connection/MessLine"/>
							<xsl:apply-templates select="@*"/>
							<xsl:apply-templates select="IPConfiguration"/>
							<xsl:element name="intranetMessagingQ">
								<xsl:apply-templates select="$Mess/@*|$Line|$Mess/comment()|$Mess/processing-instruction()|$Mess/text()"/>
							</xsl:element>
							<xsl:apply-templates select="IOScanning|globalData|SNMP|addressServer|bandwidth|comment()|processing-instruction()|text()"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>