<?xml version = "1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method = "text"/>
	
	<!-- ************************************************************* -->
	<!-- This templace write a carriage return in the text output file -->
	<!-- ************************************************************* -->
	<xsl:template name = "CRLF">
		<xsl:text disable-output-escaping="yes">&#13;</xsl:text>
	</xsl:template>

	<!-- ************************************************************* -->
	<!--								   -->
	<!-- ************************************************************* -->
	<xsl:template name = "comment">
		<xsl:if test = "comment">
			<xsl:text> (*</xsl:text>
			<xsl:value-of select = "comment"/>
			<xsl:text>*)</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************* -->
	<!--								   -->
	<!-- ************************************************************* -->
	<xsl:template name = "SimplevariableInit">
		<xsl:if test = "variableInit">
			<xsl:text> := (</xsl:text>
			<xsl:value-of select = "variableInit/@value"/>
			<xsl:if test = "variableInit/@displayBase">
				<xsl:text>,</xsl:text>
				<xsl:value-of select = "variableInit/@displayBase"/>
			</xsl:if>
			<xsl:if test = "variableInit/@displayBase1">
				<xsl:text>,</xsl:text>
				<xsl:value-of select = "variableInit/@displayBase1"/>
			</xsl:if>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************* -->
	<!--				Not used			   -->
	<!-- ************************************************************* -->
	<xsl:template name = "attribut">
		<xsl:if test = "attribut">
			<xsl:text> (</xsl:text>
			<xsl:for-each select = "variables">
				<xsl:value-of select = "attribut/@name"/>
				<xsl:text>,</xsl:text>
				<xsl:value-of select = "attribut/@value"/>
			</xsl:for-each>
			<xsl:text>) </xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************* -->
	<!--		Display instanceElementDesc			   -->
	<!-- ************************************************************* -->
	<xsl:template name = "instanceElementDesc">
		<xsl:if test = "instanceElementDesc">
			<xsl:text> := (</xsl:text>
			<xsl:for-each select = "instanceElementDesc">
				<xsl:if test = "@name">
					<xsl:value-of select = "@name"/>
					<xsl:text>:=</xsl:text>
					<xsl:value-of select = "value"/>
					<xsl:if test = "position() != last()">
						<xsl:text>,</xsl:text>
				     </xsl:if>
			     </xsl:if>
			</xsl:for-each>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************* -->
	<!--		Display Simple Variable				   -->
	<!-- ************************************************************* -->
	<xsl:template name = "variable">
		<xsl:if test="@name">
			<xsl:value-of select = "@name"/>
			<xsl:text> </xsl:text>
		</xsl:if>
		<xsl:if test="@topologicalAddress">
			<xsl:text>AT </xsl:text>
			<xsl:value-of select = "@topologicalAddress"/>
		</xsl:if>
		<xsl:text> : </xsl:text>
		<xsl:value-of select = "@typeName"/>

		<xsl:call-template name="comment"/>	
		<xsl:call-template name="SimplevariableInit"/>	

		<xsl:text>;</xsl:text><xsl:call-template name="CRLF"/>	
	</xsl:template>

	<!-- ************************************************************* -->
	<!--		Display OLDBLOCKS		(PL7 timers ...)			   -->
	<!-- ************************************************************* -->
	<xsl:template name = "OLDBLOCKS">
		<xsl:value-of select = "@name"/>
		<xsl:text> : </xsl:text>
		<xsl:value-of select = "@typeName"/>

		<xsl:call-template name="comment"/>	

		<xsl:call-template name="instanceElementDesc"/>	

		<xsl:text>;</xsl:text><xsl:call-template name="CRLF"/>	
	</xsl:template>

	<!-- ************************************************************* -->
	<!--		Main Template					   -->
	<!-- ************************************************************* -->
	<xsl:template match = "/">
		<xsl:text >[HEADER]</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text >DATE = </xsl:text><xsl:value-of select = "//fileHeader/@dateTime"/><xsl:call-template name="CRLF"/>
		<xsl:text>STANDARD = 'PLCopen  v0.1 1993'</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>SENDER = '</xsl:text><xsl:value-of select = "//fileHeader/@company"/><xsl:text> </xsl:text><xsl:value-of select = "//fileHeader/@product"/><xsl:text>'</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>[APPLICATION]</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>NAME = </xsl:text><xsl:text>'</xsl:text><xsl:value-of select = "//contentHeader/@name"/><xsl:text>'</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>DATE = </xsl:text><xsl:value-of select = "//contentHeader/@dateTime"/><xsl:call-template name="CRLF"/>
		<xsl:text>VERSION = </xsl:text><xsl:text>'</xsl:text><xsl:value-of select = "//contentHeader/@version"/><xsl:text>'</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>[DATA_UNIT]</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>DA_TYPE = </xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>LOCATION = </xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>NAME = </xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>BODY = </xsl:text><xsl:call-template name="CRLF"/>
		<xsl:text>VAR_GLOBAL</xsl:text><xsl:call-template name="CRLF"/>
		<xsl:for-each select = "//dataBlock">
			<xsl:for-each select = "variables">
				<xsl:choose>
					<xsl:when test="instanceElementDesc">
						<xsl:call-template name = "OLDBLOCKS"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name = "variable"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:for-each>
		<xsl:text>END_VAR</xsl:text><xsl:call-template name="CRLF"/>
	</xsl:template>

</xsl:stylesheet>
