<?xml version = "1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method = "text"/>
	
	<!-- ************************************************************************** -->
	<!-- This templace write a carriage return in the text output file				-->
	<!-- ************************************************************************** -->
	<xsl:template name = "CRLF">
		<xsl:text disable-output-escaping="yes">&#13;</xsl:text>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!-- This templace write a \t in the text output file							-->
	<!-- ************************************************************************** -->
	<xsl:template name = "TAB">
		<xsl:text disable-output-escaping="yes">&#9;</xsl:text>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!-- This template write the comment with the format :							-->
	<!-- "This is a Comment"														-->
	<!-- ************************************************************************** -->
	<xsl:template name = "comment">
		<xsl:if test = "comment">
			<xsl:text>"</xsl:text>
			<xsl:value-of select = "comment"/>
			<xsl:text>"</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!-- This template write the initialisation of a variable with a				-->
	<!-- based type. The format is as follow :										-->
	<!-- (variableInit/@value,variableInit/@displayBase,variableInit/@displayBase1)	-->
	<!-- ************************************************************************** -->
	<xsl:template name = "displayVariableInit">
		<xsl:if test = "./variableInit">
			<xsl:text>(</xsl:text>
			<xsl:value-of select = "variableInit/@value"/>
			<xsl:if test = "variableInit/@displayBase">
				<xsl:text>,</xsl:text>
				<xsl:value-of select = "variableInit/@displayBase"/>
			</xsl:if>
			<xsl:if test = "variableInit/@displayBase1">
				<xsl:text>,</xsl:text>
				<xsl:value-of select = "variableInit/@displayBase1"/>
			</xsl:if>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!-- This template write the initialisation of a DDT or DFB. The				-->
	<!-- format is as follow :														-->
	<!-- @name:=(InitOfDDT_DFBVars),...,value...									-->
	<!-- ************************************************************************** -->
	<xsl:template name = "displayInstanceElementDescInit">
		<xsl:for-each select = "./instanceElementDesc">
			<xsl:value-of select = "@name"/>
			<xsl:text>:=</xsl:text>
			<xsl:if test = "./instanceElementDesc">
					<xsl:text>(</xsl:text>
					<xsl:call-template name="displayInstanceElementDescInit"/>
					<xsl:text>)</xsl:text>
			</xsl:if>
			<xsl:for-each select = "././value">
				<xsl:value-of select = "."/>
				<xsl:if test = "position() != last()">
					<xsl:text>,</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test = "position() != last()">
				<xsl:text>,</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!-- This template will start writting theinitialisation of a DDT or DFB.		-->
	<!-- The format is as follow :													-->
	<!-- (instanceElementDescInit)													-->
	<!-- ************************************************************************** -->
	<xsl:template name = "displayInstanceElementDesc">
		<xsl:if test = "instanceElementDesc">
			<xsl:text>(</xsl:text>
			<xsl:call-template name="displayInstanceElementDescInit"/>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ************************************************************************** -->
	<!--		Display Simple Variable												-->
	<!-- ************************************************************************** -->
	<xsl:template name = "displayVariable">
		<xsl:value-of select = "@name"/>
		<xsl:call-template name="TAB"/>

		<xsl:value-of select = "@topologicalAddress"/>
		<xsl:call-template name="TAB"/>

		<xsl:value-of select = "@typeName"/>
		<xsl:call-template name="TAB"/>

		<xsl:call-template name="comment"/>	
		<xsl:call-template name="TAB"/>

		<xsl:if test = "instanceElementDesc">
			<xsl:call-template name="displayInstanceElementDesc"/>
		</xsl:if>
		<xsl:if test = "variableInit">
			<xsl:call-template name="displayVariableInit"/>	
		</xsl:if>

		<xsl:call-template name="CRLF"/>	
	</xsl:template>

	<!-- ************************************************************************** -->
	<!--		Main Template														-->
	<!-- ************************************************************************** -->
	<xsl:template match = "/">
		<xsl:for-each select = "//dataBlock">
			<xsl:for-each select = "variables">
				<xsl:call-template name = "displayVariable"/>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
